from_raw

Function from_raw 

pub unsafe fn from_raw<T>(pointer: *mut T) -> Box<T>
Tell Rust to take back the control over memory.

Safety

pointer must come from Box::into_raw for the same T, must not be null, and must not have already been reclaimed.